==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Dawkowanie.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Dawkowanie extends GenericDPSObject {
    /**
     * DAWKOWANIE.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DAWKOWANIE.POPRZEDNIE_DAWKOWANIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long poprzednieDawkowanieId;

    /**
     * DAWKOWANIE.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * DAWKOWANIE.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DAWKOWANIE.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DAWKOWANIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DAWKOWANIE.POPRZEDNIE_DAWKOWANIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPoprzednieDawkowanieId() {
        return poprzednieDawkowanieId;
    }

    /**
     * DAWKOWANIE.POPRZEDNIE_DAWKOWANIE_ID
     *
     * @param poprzednieDawkowanieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPoprzednieDawkowanieId(Long poprzednieDawkowanieId) {
        this.poprzednieDawkowanieId = poprzednieDawkowanieId;
    }

    /**
     * @return DAWKOWANIE.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * DAWKOWANIE.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return DAWKOWANIE.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * DAWKOWANIE.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Dawkowanie other = (Dawkowanie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPoprzednieDawkowanieId() == null ? other.getPoprzednieDawkowanieId() == null : this.getPoprzednieDawkowanieId().equals(other.getPoprzednieDawkowanieId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPoprzednieDawkowanieId() == null) ? 0 : getPoprzednieDawkowanieId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", poprzednieDawkowanieId=").append(poprzednieDawkowanieId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", dataOd=").append(dataOd);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Dawkowanie.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Dawkowanie extends GenericDPSObject {
    /**
     * DAWKOWANIE.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DAWKOWANIE.POPRZEDNIE_DAWKOWANIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long poprzednieDawkowanieId;

    /**
     * DAWKOWANIE.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * DAWKOWANIE.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DAWKOWANIE.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DAWKOWANIE.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DAWKOWANIE.POPRZEDNIE_DAWKOWANIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPoprzednieDawkowanieId() {
        return poprzednieDawkowanieId;
    }

    /**
     * DAWKOWANIE.POPRZEDNIE_DAWKOWANIE_ID
     *
     * @param poprzednieDawkowanieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPoprzednieDawkowanieId(Long poprzednieDawkowanieId) {
        this.poprzednieDawkowanieId = poprzednieDawkowanieId;
    }

    /**
     * @return DAWKOWANIE.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * DAWKOWANIE.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return DAWKOWANIE.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * DAWKOWANIE.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Dawkowanie other = (Dawkowanie) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getPoprzednieDawkowanieId() == null ? other.getPoprzednieDawkowanieId() == null : this.getPoprzednieDawkowanieId().equals(other.getPoprzednieDawkowanieId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getPoprzednieDawkowanieId() == null) ? 0 : getPoprzednieDawkowanieId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", poprzednieDawkowanieId=").append(poprzednieDawkowanieId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", dataOd=").append(dataOd);
        sb.append("]");
        return sb.toString();
    }
}
